Package: fakemake
Title: Mock the Unix Make Utility
Version: 1.11.1
Authors@R: 
    person(given = "Andreas Dominik",
           family = "Cullmann",
           role = c("aut", "cre"),
           email = "fvafrcu@mailbox.org")
Description: Use R as a minimal build system. This might come in
    handy if you are developing R packages and can not use a proper build
    system. Stay away if you can (use a proper build system).
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrcu/fakemake
Depends: R (>= 3.3.0)
Imports: graphics, fritools, igraph, MakefileR, utils
Suggests: cleanr, covr, cyclocomp, devtools, hunspell, knitr, lintr,
        pkgbuild, pkgload, rasciidoc, rmarkdown, roxygen2, rprojroot,
        RUnit, spelling, testthat, withr, usethis
VignetteBuilder: knitr, rasciidoc
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-08-15 21:48:05 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2023-08-15 22:10:01 UTC
Built: R 4.6.0; ; 2026-04-26 03:34:01 UTC; unix
