# Generated by roxygen2: do not edit by hand

export(add_target)
export(get_target)
export(make)
export(provide_make_list)
export(read_makefile)
export(remove_target)
export(sink_all)
export(touch)
export(visualize)
export(write_makefile)
